==> massxpert2_8.4.1.orig.tar.gz: massxpert2-8.4.1/src/gui/MzLabMassBasedActionsDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
#define MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP

// #pragma message("including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")

/////////////////////// Qt includes


/////////////////////// Local includes
#include "ui_MzLabMassBasedActionsDlg.h"
#include "libmass/globals.hpp"
#include "MzLabWnd.hpp"

namespace msxps
{

	namespace massxpert
	{



class MzLabMassBasedActionsDlg : public QDialog
{
  Q_OBJECT

  private:
  Ui::MzLabMassBasedActionsDlg m_ui;

  QString m_configSettingsFilePath;

  MzLabWnd *mp_mzLabWnd;

  void closeEvent(QCloseEvent *event);

  public:
  MzLabMassBasedActionsDlg(QWidget *, const QString &configSettingsFilePath);

  ~MzLabMassBasedActionsDlg();

  private slots:
  void applyMassPushButton();
  void applyThresholdPushButton();
};

} // namespace massxpert

} // namespace msxps


#endif // MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
// #pragma message("done...including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")

==> massxpert2_8.5.0.orig.tar.gz: massxpert2-8.5.0/src/gui/MzLabMassBasedActionsDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
#define MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP

// #pragma message("including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")

/////////////////////// Qt includes


/////////////////////// Local includes
#include "ui_MzLabMassBasedActionsDlg.h"
#include <libXpertMass/globals.hpp>
#include "MzLabWnd.hpp"

namespace MsXpS
{

	namespace massxpert
	{



class MzLabMassBasedActionsDlg : public QDialog
{
  Q_OBJECT

  private:
  Ui::MzLabMassBasedActionsDlg m_ui;

  QString m_configSettingsFilePath;

  MzLabWnd *mp_mzLabWnd;

  void closeEvent(QCloseEvent *event);

  public:
  MzLabMassBasedActionsDlg(QWidget *, const QString &configSettingsFilePath);

  ~MzLabMassBasedActionsDlg();

  private slots:
  void applyMassPushButton();
  void applyThresholdPushButton();
};

} // namespace massxpert

} // namespace MsXpS


#endif // MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
// #pragma message("done...including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")
